@@ -24,7 +24,7 @@ SOFTWARE.
 import socket
 import json
 import time
-import py_eureka_client.http_client as http_client
+from py_eureka_client.http_client import http_client
 from py_eureka_client.logger import get_logger
 
 _logger = get_logger("aws_info_loader")
@@ -48,29 +48,35 @@ class AmazonInfo:
                 return True
             except socket.error:
                 idx = i + 1
-                _logger.debug(f"Try amazon metadata services connectivity fail, retry ({idx}/{_CONNECTIVITY_TEST_TIMES})")
+                _logger.debug(
+                    f"Try amazon metadata services connectivity fail, retry ({idx}/{_CONNECTIVITY_TEST_TIMES})")
                 time.sleep(1)
-        _logger.warn(f"Cannot connect to amazon metadata services in address [{_AWS_METADATA_SERVICE_IP}]")
+        _logger.warn(
+            f"Cannot connect to amazon metadata services in address [{_AWS_METADATA_SERVICE_IP}]")
         return False
 
-    def get_ec2_metadata(self, meta_path, default_value="", ignore_error=False):
+    async def get_ec2_metadata(self, meta_path, default_value="", ignore_error=False):
         if not self.__can_access:
-            _logger.warn(f"Cannot connect to amazon metadata services in address [{_AWS_METADATA_SERVICE_IP}], return default value. ")
+            _logger.warn(
+                f"Cannot connect to amazon metadata services in address [{_AWS_METADATA_SERVICE_IP}], return default value. ")
             return default_value
         try:
-            return http_client.load(f"{_AWS_METADATA_SERVICE_URL}meta-data/{meta_path}")[0]
+            res = await http_client.urlopen(f"{_AWS_METADATA_SERVICE_URL}meta-data/{meta_path}")
+            return res.body_text
         except Exception:
             log_excep = _logger.debug if ignore_error else _logger.exception
             log_excep(f"error when loading metadata from aws {meta_path}")
             return default_value
 
-    def get_instance_identity_document(self, default_value={}):
+    async def get_instance_identity_document(self, default_value={}):
         if not self.__can_access:
-            _logger.warn(f"Cannot connect to amazon metadata services in address [{_AWS_METADATA_SERVICE_IP}], return default value. ")
+            _logger.warn(
+                f"Cannot connect to amazon metadata services in address [{_AWS_METADATA_SERVICE_IP}], return default value. ")
             return default_value
         try:
-            doc = http_client.load(f"{_AWS_METADATA_SERVICE_URL}dynamic/instance-identity/document")[0]
-            return json.loads(doc)
+            doc = await http_client.urlopen(f"{_AWS_METADATA_SERVICE_URL}dynamic/instance-identity/document")
+            return json.loads(doc.body_text)
         except Exception:
-            _logger.exception("error when loading dynamic instance identity document from aws")
+            _logger.exception(
+                "error when loading dynamic instance identity document from aws")
             return default_value
