@@ -24,7 +24,8 @@ SOFTWARE.
 
 import dns.resolver
 
+
 def get_txt_dns_record(domain):
     records = dns.resolver.resolve(domain, 'TXT')
     if len(records):
-        return str(records[0]).replace('"', "").split(' ')
+        return str(records[0]).replace('"', '').split(' ')
