@@ -142,9 +142,9 @@ class HttpClient:
         if isinstance(request, HttpRequest):
             req = request
         elif isinstance(request, str):
-            req = HttpRequest(request)
+            req = HttpRequest(request, headers={'Accept-Encoding': 'gzip'})
         else:
-            raise URLError("Unvalid URL")
+            raise URLError("Invalid URL")
 
         res = urllib.request.urlopen(req._to_urllib_request(), data=data, timeout=timeout)
         return HttpResponse(res)
